@@ -374,6 +374,32 @@ try
     }
 
     *handle = sp;
+
+    // we check if rocsolver logging needs to be started
+    bool enable_rocsolver_logging = false;
+    // check for ROCSOLVER_LAYER environment variable
+    if(const char* str_layer_mode = std::getenv("ROCSOLVER_LAYER"))
+    {
+        errno      = 0;
+        long value = strtol(str_layer_mode, 0, 0);
+        if(!(errno || value < 0 || size_t(value) > size_t(UINT32_MAX)))
+            enable_rocsolver_logging = true;
+    }
+
+    // check for ROCSOLVER_LEVELS environment variable
+    if(const char* str_max_level = std::getenv("ROCSOLVER_LEVELS"))
+    {
+        errno      = 0;
+        long value = strtol(str_max_level, 0, 0);
+        if(!(errno || value < 1 || size_t(value) > size_t(INT_MAX)))
+            enable_rocsolver_logging = true;
+    }
+
+    if(enable_rocsolver_logging)
+    {
+        rocsolver_log_begin();
+    }
+
     return HIPSOLVER_STATUS_SUCCESS;
 }
 catch(...)
@@ -395,6 +421,31 @@ try
     cholmod_finish(&sp->c_handle);
     delete sp;
 
+    // we check if rocsolver logging needs to be ended
+    bool enable_rocsolver_logging = false;
+    // check for ROCSOLVER_LAYER environment variable
+    if(const char* str_layer_mode = std::getenv("ROCSOLVER_LAYER"))
+    {
+        errno      = 0;
+        long value = strtol(str_layer_mode, 0, 0);
+        if(!(errno || value < 0 || size_t(value) > size_t(UINT32_MAX)))
+            enable_rocsolver_logging = true;
+    }
+
+    // check for ROCSOLVER_LEVELS environment variable
+    if(const char* str_max_level = std::getenv("ROCSOLVER_LEVELS"))
+    {
+        errno      = 0;
+        long value = strtol(str_max_level, 0, 0);
+        if(!(errno || value < 1 || size_t(value) > size_t(INT_MAX)))
+            enable_rocsolver_logging = true;
+    }
+
+    if(enable_rocsolver_logging)
+    {
+        rocsolver_log_end();
+    }
+
     return HIPSOLVER_STATUS_SUCCESS;
 }
 catch(...)
